%Mit dieser Ansteuerung lsst sich der Betriebsfestigkeitsfaktor K_BKMK 
%nach dem Verfahren Miner konsequent fr den Bauteil-Whlerlinien Typ I 
%nach Kapitel 4.4.3.5.2, FKM-Richtlinie 7. Aufl. 2020, berechnen. Dabei 
%sind vorab vom Nutzer die folgenden Gren nach FKM-Richtlinie zu 
%bestimmen (Eingabe ab Zeile 26 in dieser Ansteuerung):
%sigma_ai = Kollektivamplituden passend zu n_i (Spaltenvektor)
%n_i      = Kollektivstufenhufigkeiten passend zu sigma_ai (Spaltenvektor)
%k        = Whlerlinienneigung nach Kap. 4.4.3.4
%N_D      = Knickpunktzyklenzahl der Bauteil-Whlerlinie nach Kap. 4.4.3.4
%D_mmin   = Untergrenze der effektiven Miner-Summe nach Tab. 4.4.4
%
%Diese Ansteuerung erfordert die folgenden, nicht-intrinsichen
%Funktionen:
%Iteration_K_BKMK
%sigma_aquschlangestart
%
%nderungshistorie:
%02. November 2016:
%   Dr.-Ing. C. Mller (AUDI AG)
%       Erstausgabe
%17. Januar 2021
%   Dr.-Ing. C. Mller (AUDI AG)
%       Anpassung auf die 7. Auflage der FKM-Richtlinie 2020
%15. Mai 2023
%   Dr.-Ing. M. Wchter (IMAB)
%       Fehlerkorrektur (Kommentierung und Ergebnisausgabe)


%Leeren des Command-Windows, lschen des Workspaces, schlieen aller
%Figures:
clc
clear all
close all


%Vorgaben nach FKM-Richtlinie:
sigma_ai = [1.00 0.95 0.85 0.70 0.50 0.30 0.25]';   %Kollektivamplituden passend zu n_i (Spaltenvektor erzeugt durch Transponieren)
n_i      = [2 100 2000 30000 40000 50000 890000]';  %Kollektivstufenhufigkeiten passend zu sigma_ai (Spaltenvektor erzeugt durch Transponieren)
k        = 5;                                       %Whlerlinienneigung nach Kap. 4.4.3.4
N_D      = 10^6;                                    %Knickpunktzyklenzahl der Bauteil-Whlerlinie nach Kap. 4.4.3.4
D_mmin   = 0.3;                                     %Untergrenze der effektiven Miner-Summe nach Tab. 4.4.4


%Vorgabe der Iterationsgenauigkeit fr die geforderte Lebensdauer
%(Standardwert eps = 1):
eps      = 10^0;


%berprfe, ob sigma_ai fallend sortiert ist, vgl. Kapitel 4.1.3.1:
dummy    = [sigma_ai, n_i];
dummy    = sortrows(dummy,-1);
sigma_ai = dummy(:,1);
n_i      = dummy(:,2);


%Berechne geforderte Zyklenzahl N_quer, vgl. Kapitel 4.1.3.1:
N_quer = sum(n_i);

%

%Berechne K_BKMK, vgl. Kapitel 4.4.3.5.2:
[K_BKMK] = Iteration_K_BKMK(sigma_ai, n_i, k, N_D, N_quer, D_mmin, eps)
msgbox({['Iterative Berechnung des Betriebsfestigkeitsfaktor K_{BKMK}' ...
        ' nach dem Verfahren Miner konsequent, FKM-Richtlinie' ...
        ' 7. Aufl. 2020.']; ...
        ''; ...
        ['K_{BKMK} = ' num2str(K_BKMK, '%.4f')]});